/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.printpublisher.handler;

import java.util.UUID;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.handlers.HandlerUtil;
import org.jdom.Element;

import eu.etaxonomy.cdm.api.application.ICdmRepository;
import eu.etaxonomy.cdm.print.IXMLEntityFactory;
import eu.etaxonomy.cdm.print.PublishConfigurator;
import eu.etaxonomy.cdm.print.out.pdf.PdfOutputModule;
import eu.etaxonomy.cdm.print.out.xml.XMLOutputModule;
import eu.etaxonomy.taxeditor.editor.TaxonEditorInput;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.printpublisher.PrintUtil;
import eu.etaxonomy.taxeditor.printpublisher.wizard.DirectPublishingWizard;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>GeneratePdfHandler class.</p>
 *
 * @author n.hoffmann
 * @created Jul 20, 2010
 * @version 1.0
 */
public class GeneratePdfHandler extends AbstractHandler {
	
	private PublishConfigurator configurator;

	/** {@inheritDoc} */
	public Object execute(ExecutionEvent event) throws ExecutionException {
		// make the editors taxon the selected taxon to export
		IEditorPart editor = HandlerUtil.getActiveEditor(event);	

		IEditorInput input = editor.getEditorInput();
		
		if(!(input instanceof TaxonEditorInput)){
			MessagingUtils.warningDialog("PDF generation not supported for selected input", this, "Generating PDF output is not supported for the current active editor");
			
			return null;
		}
		
		configurator = PublishConfigurator.NewLocalInstance((ICdmRepository) CdmStore.getCurrentApplicationConfiguration());
		
		Element taxonNodeElement = getTaxonNodeElement((TaxonEditorInput) input);
		configurator.addSelectedTaxonNodeElements(taxonNodeElement);
		
		configurator.setDoPublishEntireBranches(false);
		
		configurator.addOutputModule(new PdfOutputModule());
		configurator.addOutputModule(new XMLOutputModule());
		
		DirectPublishingWizard wizard = new DirectPublishingWizard(configurator);
		WizardDialog dialog = new WizardDialog(HandlerUtil.getActiveShell(event), wizard);
		
		dialog.open();
		
		return null;
	}
	
	private Element getTaxonNodeElement(TaxonEditorInput input){
		
		UUID taxonNodeUuid = input.getTaxonNode().getUuid();
		
		IXMLEntityFactory factory = configurator.getFactory();
		
		Element taxonNodeElement = factory.getTaxonNode(taxonNodeUuid);
		
		return taxonNodeElement;
	}
}
