/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.printpublisher.wizard;

import java.io.File;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

/**
 * <p>SelectFolderWizardPage class.</p>
 *
 * @author n.hoffmann
 * @created Apr 7, 2010
 * @version 1.0
 */
public class SelectDirectoryWizardPage extends AbstractPublishWizardPage implements IHasPersistableSettings {
	private static final String DIALOG_SETTING_OUTPUT_DIRECTORY = "dialogSettingOutputDirectory";
	private Composite composite;
	private DirectoryDialog folderDialog;
	private Text text_folder;

	/**
	 * <p>Constructor for SelectFolderWizardPage.</p>
	 *
	 * @param pageName a {@link java.lang.String} object.
	 */
	public SelectDirectoryWizardPage(String pageName) {
		super(pageName);
		setTitle("Select a folder");
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
	 */
	/** {@inheritDoc} */
	public void createControl(Composite parent) {
//		configurator = ((IPublishConfigurer) getWizard()).getConfigurator();
		
		composite = new Composite(parent, SWT.NULL);
		composite.setLayout(new GridLayout());
		
		Label folderLabel = new Label(composite, SWT.NONE);
		folderLabel.setText("Folder");

		folderDialog = new DirectoryDialog(parent.getShell());

		text_folder = new Text(composite, SWT.BORDER);
		text_folder.setEditable(false);
		text_folder.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));

		Button button = new Button(composite, SWT.PUSH);
		button.setText("Browse...");

		button.addSelectionListener(new SelectionAdapter(){
			/* (non-Javadoc)
		 	* @see org.eclipse.swt.events.SelectionAdapter#widgetSelected(org.eclipse.swt.events.SelectionEvent)
		 	*/
			@Override
			public void widgetSelected(SelectionEvent e) {
				super.widgetSelected(e);
				String path = folderDialog.open();
				if(path != null){ // a folder was selected
					setDirectory(path);
				}
			}
		});
		
		loadSettings();
		
		setControl(composite);
	}
	
	@Override
	public void loadSettings() {
		String directory = getDialogSettingValue(DIALOG_SETTING_OUTPUT_DIRECTORY);
		
		if(directory != null){
			setDirectory(directory);
		}
	}
	
	private void setDirectory(String directory){
		text_folder.setText(directory);
		getConfigurator().setExportFolder(new File(directory));

		putDialogSettingValue(DIALOG_SETTING_OUTPUT_DIRECTORY, directory);
		
		setPageComplete(true);
	}
	
	/** {@inheritDoc} */
	@Override
	public boolean isPageComplete() {
		return getConfigurator().getExportFolder() != null;
	}
}
